==> eiffelstudio-18.07.10.1981.tar: F_code/C7/st305.c <==
/*
 * Code for class ST_WORD_WRAPPER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st305.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ST_WORD_WRAPPER}.make */
void F950_6212 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 79L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTLE;
}

/* {ST_WORD_WRAPPER}.set_maximum_text_width */
void F950_6218 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) arg1;
}

/* {ST_WORD_WRAPPER}.set_new_line_indentation */
void F950_6219 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) = (EIF_INTEGER_32) arg1;
}

/* {ST_WORD_WRAPPER}.wrapped_string */
EIF_REFERENCE F950_6220 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc6);
	RTLR(5,Result);
	RTLIU(6);
	
	RTGC;
	tr1 = RTOSCF(5937,F931_5937,(Current));
	loc1 = F920_5887(RTCW(tr1), arg1);
	F950_6221(Current, loc1);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
	tr1 = RTLNS(eif_new_type(914, 0x00).id, 914, _OBJSIZ_1_1_0_3_0_0_0_0_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_);
	F913_5661(RTCW(tr1), (EIF_CHARACTER_8) ' ', ti4_1);
	loc6 = (EIF_REFERENCE) tr1;
	tr1 = RTLNS(eif_new_type(914, 0x00).id, 914, _OBJSIZ_1_1_0_3_0_0_0_0_);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	F913_5660(RTCW(tr1), ti4_1);
	Result = (EIF_REFERENCE) tr1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	loc4 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
	for (;;) {
		if ((EIF_BOOLEAN) (loc4 > loc2)) break;
		if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (loc4 + loc3) <= loc2)) {
			loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 + loc3);
			for (;;) {
				tb1 = '\01';
				if (!(EIF_BOOLEAN)(loc5 == loc4)) {
					tc1 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R3056[Dtype(loc1)-665])(RTCW(loc1), loc5));
					tb1 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) ' ');
				}
				if (tb1) break;
				loc5--;
			}
		} else {
			loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
		}
		if ((EIF_BOOLEAN)(loc5 == loc4)) {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_2_))++;
			loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc4 + loc3) - ((EIF_INTEGER_32) 1L));
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4235[Dtype(loc1)-910])(RTCW(loc1), loc4, loc5);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4415[Dtype(Result)-914])(RTCW(Result), tr1);
		} else {
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4235[Dtype(loc1)-910])(RTCW(loc1), loc4, (EIF_INTEGER_32) (loc5 - ((EIF_INTEGER_32) 1L)));
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4415[Dtype(Result)-914])(RTCW(Result), tr1);
		}
		loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc5 + ((EIF_INTEGER_32) 1L));
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc4 <= ti4_1)) {
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_CHARACTER_8)) R4417[Dtype(Result)-914])(RTCW(Result), (EIF_CHARACTER_8) '\012');
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4415[Dtype(Result)-914])(RTCW(Result), loc6);
		}
		loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_);
		loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ti4_1);
	}
	RTLE;
	return Result;
}

/* {ST_WORD_WRAPPER}.canonify_whitespace */
void F950_6221 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_8 loc3 = (EIF_CHARACTER_8) 0;
	EIF_CHARACTER_8 tc1;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R3056[Dtype(arg1)-665])(RTCW(arg1), loc1));
		if (F950_6222(Current, loc3)) {
			tc1 = (EIF_CHARACTER_8) ' ';
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R1849[Dtype(arg1)-690])(RTCW(arg1), (EIF_REFERENCE) &tc1, (EIF_REFERENCE) &loc1);
		}
		loc1++;
	}
	RTLE;
}

/* {ST_WORD_WRAPPER}.is_space */
EIF_BOOLEAN F950_6222 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 == (EIF_CHARACTER_8) ' ') || (EIF_BOOLEAN)(arg1 == (EIF_CHARACTER_8) '\011')) || (EIF_BOOLEAN)(arg1 == (EIF_CHARACTER_8) '\012')) || (EIF_BOOLEAN)(arg1 == (EIF_CHARACTER_8) '\015'));
	return Result;
}

void EIF_Minit305 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C7/st305.c <==
/*
 * Code for class ST_WORD_WRAPPER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st305.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ST_WORD_WRAPPER}.make */
void F951_6262 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 79L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTLE;
}

/* {ST_WORD_WRAPPER}.set_maximum_text_width */
void F951_6268 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) arg1;
}

/* {ST_WORD_WRAPPER}.set_new_line_indentation */
void F951_6269 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) = (EIF_INTEGER_32) arg1;
}

/* {ST_WORD_WRAPPER}.wrapped_string */
EIF_REFERENCE F951_6270 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc6);
	RTLR(5,Result);
	RTLIU(6);
	
	RTGC;
	tr1 = RTOSCF(6001,F933_6001, (Current));
	loc1 = F922_5951(RTCW(tr1), arg1);
	F951_6271(Current, loc1);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
	loc6 = RTLNS(eif_new_type(916, 0x01).id, 916, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F915_5725(RTCW(loc6), (EIF_CHARACTER_8) ' ', *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_));
	Result = RTLNS(eif_new_type(916, 0x01).id, 916, _OBJSIZ_1_1_0_3_0_0_0_0_);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	F915_5724(RTCW(Result), ti4_1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	loc4 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
	for (;;) {
		if ((EIF_BOOLEAN) (loc4 > loc2)) break;
		if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (loc4 + loc3) <= loc2)) {
			loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 + loc3);
			for (;;) {
				tb1 = '\01';
				if (!(EIF_BOOLEAN)(loc5 == loc4)) {
					tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R3091[Dtype(RTCW(loc1))-668])(loc1, loc5));
					tb1 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) ' ');
				}
				if (tb1) break;
				loc5--;
			}
		} else {
			loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
		}
		if ((EIF_BOOLEAN)(loc5 == loc4)) {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_2_))++;
			loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc4 + loc3) - ((EIF_INTEGER_32) 1L));
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4287[Dtype(RTCW(loc1))-912])(loc1, loc4, loc5);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4467[Dtype(RTCW(Result))-916])(Result, tr1);
		} else {
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4287[Dtype(RTCW(loc1))-912])(loc1, loc4, (EIF_INTEGER_32) (loc5 - ((EIF_INTEGER_32) 1L)));
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4467[Dtype(RTCW(Result))-916])(Result, tr1);
		}
		loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc5 + ((EIF_INTEGER_32) 1L));
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc4 <= ti4_1)) {
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_CHARACTER_8)) R4469[Dtype(RTCW(Result))-916])(Result, (EIF_CHARACTER_8) '\012');
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4467[Dtype(RTCW(Result))-916])(Result, loc6);
		}
		loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_);
		loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ti4_1);
	}
	RTLE;
	return Result;
}

/* {ST_WORD_WRAPPER}.canonify_whitespace */
void F951_6271 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_8 loc3 = (EIF_CHARACTER_8) 0;
	EIF_CHARACTER_8 tc1;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R3091[Dtype(RTCW(arg1))-668])(arg1, loc1));
		if (F951_6272(Current, loc3)) {
			tc1 = (EIF_CHARACTER_8) ' ';
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R2880[Dtype(RTCW(arg1))-693])(arg1, (EIF_REFERENCE) &tc1, (EIF_REFERENCE) &loc1);
		}
		loc1++;
	}
	RTLE;
}

/* {ST_WORD_WRAPPER}.is_space */
EIF_BOOLEAN F951_6272 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 == (EIF_CHARACTER_8) ' ') || (EIF_BOOLEAN)(arg1 == (EIF_CHARACTER_8) '\011')) || (EIF_BOOLEAN)(arg1 == (EIF_CHARACTER_8) '\012')) || (EIF_BOOLEAN)(arg1 == (EIF_CHARACTER_8) '\015'));
	return Result;
}

void EIF_Minit305 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
